@@ -26,6 +26,8 @@
 #include "object.h"
 #include "loader.h"
 
+#define DOODLEHASH_FEMALE 0
+#define DOODLEHASH_MALE 1
 int gdk_pixmap_get_width(GdkPixmap *pixmap)
 {
   int width;
@@ -55,7 +57,7 @@ double get_aspect_ratio(guint32 inner_width, guint32 inner_height, guint32 width
   return aspect;
 }
 
-int get_random_file(const gchar *subdir, const gchar *ext, gchar **file)
+int get_random_file(int gender, const gchar *subdir, const gchar *ext, gchar **file)
 {
   gchar * path = get_svg_path (subdir);
   GDir *dir = g_dir_open (path, 0, NULL);
@@ -66,6 +68,8 @@ int get_random_file(const gchar *subdir, const gchar *ext, gchar **file)
       const char **files = NULL;
       while ((basename = g_dir_read_name (dir)) != NULL)
         {
+          if (g_str_has_prefix(basename, gender == 0 ? "m-" : "f-"))
+            continue;
           if (g_str_has_suffix(basename, ext))
             {
               num_files++;
@@ -81,13 +85,13 @@ int get_random_file(const gchar *subdir, const gchar *ext, gchar **file)
   return dir && num_files ? 0 : 1;
 }
 
-int get_random_file_pair(const gchar *subdir, const gchar *ext, gchar **left, gchar **right)
+int get_random_file_pair(int gender, const gchar *subdir, const gchar *ext, gchar **left, gchar **right)
 {
   int retval = 1;
   gchar *left_ext = g_strdup_printf("%s%s", "-left", ext);
   if (left_ext)
     {
-      retval = get_random_file(subdir, left_ext, left);
+      retval = get_random_file(gender, subdir, left_ext, left);
       if (retval == 0)
         {
           gchar *base = g_path_get_basename(*left);
@@ -97,7 +101,7 @@ int get_random_file_pair(const gchar *subdir, const gchar *ext, gchar **left, gc
               gchar *right_ext = g_strdup_printf("%s%s%s", base, "-right",ext);
               if (right_ext)
                 {
-                  retval = get_random_file(subdir, right_ext, right);
+                  retval = get_random_file(gender, subdir, right_ext, right);
                   g_free(right_ext);
                 }
               g_free(base);
@@ -536,7 +540,7 @@ void draw_head(DoodleHashHead* head, GdkPixmap *pixmap, guint32 width, guint32 h
   g_object_unref (head_pixbuf);
 }
 
-int get_same_width_svg_file(const char *infile, const char *subdir, const char *ext, gchar **file)
+int get_same_width_svg_file(int gender, const char *infile, const char *subdir, const char *ext, gchar **file)
 {
   guint32 width = doodlehash_object_get_width_from_svg_file(infile);
   if (width == 0)
@@ -550,6 +554,8 @@ int get_same_width_svg_file(const char *infile, const char *subdir, const char *
       const char **files = NULL;
       while ((basename = g_dir_read_name (dir)) != NULL)
         {
+          if (g_str_has_prefix(basename, gender == DOODLEHASH_FEMALE ? "m-" : "f-"))
+            continue;
           *file = g_build_filename (DOODLEHASH_DATADIR, subdir, basename, NULL);
           if (g_str_has_suffix(basename, ext) &&
               doodlehash_object_get_width_from_svg_file(*file) == width)
@@ -651,18 +657,23 @@ GdkPixbuf* doodlehash_new_pixbuf(const gchar *hash, guint32 height, guint32 widt
   gchar *cheek_right_file = NULL;
   gchar *spectacles_file = NULL;
   srand(get_num_from_hash(hash));
-  get_random_file_pair("ears", ".svg", &ear_left_file, &ear_right_file);
-  get_random_file_pair("earrings", ".svg", &earring_left_file, &earring_right_file);
-  get_random_file("eyes", ".svg", &eyes_file);
-  get_random_file("heads", ".svg", &head_file);
-  get_random_file("moustaches", ".svg", &moustache_file);
-  get_random_file("mouths", ".svg", &mouth_file);
-  get_random_file("noses", ".svg", &nose_file);
-  get_random_file_pair ("eyebrows", ".svg", &eyebrow_left_file, &eyebrow_right_file);
-  get_random_file("chins", ".svg", &chin_file);
-  get_random_file_pair ("cheeks", ".svg", &cheek_left_file, &cheek_right_file);
-  get_same_width_svg_file(head_file, "hair", ".svg", &hair_file);
-  get_same_width_svg_file(eyes_file, "spectacles", ".svg", &spectacles_file);
+  int gender;
+  if (rand() % 2 == 0)
+    gender = DOODLEHASH_FEMALE;
+  else
+    gender = DOODLEHASH_MALE;
+  get_random_file_pair(gender, "ears", ".svg", &ear_left_file, &ear_right_file);
+  get_random_file_pair(gender, "earrings", ".svg", &earring_left_file, &earring_right_file);
+  get_random_file(gender, "eyes", ".svg", &eyes_file);
+  get_random_file(gender, "heads", ".svg", &head_file);
+  get_random_file(gender, "moustaches", ".svg", &moustache_file);
+  get_random_file(gender, "mouths", ".svg", &mouth_file);
+  get_random_file(gender, "noses", ".svg", &nose_file);
+  get_random_file_pair (gender, "eyebrows", ".svg", &eyebrow_left_file, &eyebrow_right_file);
+  get_random_file(gender, "chins", ".svg", &chin_file);
+  get_random_file_pair (gender, "cheeks", ".svg", &cheek_left_file, &cheek_right_file);
+  get_same_width_svg_file(gender, head_file, "hair", ".svg", &hair_file);
+  get_same_width_svg_file(gender, eyes_file, "spectacles", ".svg", &spectacles_file);
   //printf("using these files:\n"
          //"%s\n" "%s\n" "%s\n" "%s\n" "%s\n" "%s\n" "%s\n" "%s\n" "%s\n" "%s\n"
          //"%s\n" "%s\n" "%s\n" "%s\n" "%s\n" "%s\n",
