@@ -10,7 +10,7 @@ int main(int argc, char **argv)
   if (retval != 0)
     return retval;
 
-  GdkPixbuf *pixbuf = doodlehash_new_pixbuf("blah1", 512, 512);
+  GdkPixbuf *pixbuf = doodlehash_new_pixbuf("bla", 512, 512);
   if (pixbuf)
     {
       gchar *temp_file = NULL;
